/*
 * Copyright (c) 2008-2010 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.
 *    
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *    
 *  * Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *  * Neither the name of Nokia Corporation nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *    
 *    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 *    AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *    IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *    DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 *    FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *    DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 *    SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 *    OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *    OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *    
 *    Description:  
 */


// INCLUDE FILES
#include "CalendarAPIexampleAppUi.h"
#include "CalendarAPIexampleSearchView.h"
#include "CalendarAPIexampleEntryView.h"
#include "CalendarAPIexampleEntriesView.h"

#include "CalendarAPIexampleEngine.h"
#include "CalendarAPIexampleDocument.h"
#include "CalendarAPIexample.pan"

#include <avkon.hrh>

// ================= MEMBER FUNCTIONS =======================
//
// ----------------------------------------------------------
// CCalendarAPIexampleAppUi::ConstructL()
// 
// ----------------------------------------------------------
//
void CCalendarAPIexampleAppUi::ConstructL()
    {
    BaseConstructL(EAknEnableSkin);
    
    iEngine = CCalendarAPIexampleEngine::NewL(*this);    
    
    iSearchView = CCalendarAPIexampleSearchView::NewL(*iEngine);
    AddViewL( iSearchView );      // transfer ownership to AppUi

    iEntryView = CCalendarAPIexampleEntryView::NewL(*iEngine);
    AddViewL( iEntryView );      // transfer ownership to AppUi

    iEntriesView = CCalendarAPIexampleEntriesView::NewL(*iEngine);
    AddViewL( iEntriesView );      // transfer ownership to AppUi

    ActivateView(iSearchView->Id());
    }

// ----------------------------------------------------
// CCalendarAPIexampleAppUi::~CCalendarAPIexampleAppUi()
// Destructor
// Frees reserved resources
// ----------------------------------------------------
//
CCalendarAPIexampleAppUi::~CCalendarAPIexampleAppUi()
    {
    delete iEngine;
    iEngine=NULL;
    }

// ----------------------------------------------------
// CCalendarAPIexampleAppUi::HandleCommandL(TInt aCommand)
// takes care of command handling
// ----------------------------------------------------
//
void CCalendarAPIexampleAppUi::HandleCommandL(TInt aCommand)
    {
    switch ( aCommand )
        {
        case EAknSoftkeyBack:
        case EEikCmdExit:
            {
            Exit();
            break;
            }
        default:
            break;      
        }
    }

void CCalendarAPIexampleAppUi::ActivateView(TUid aViewId)
    {
    TRAPD(err,ActivateLocalViewL(aViewId) );
    if( err )
        {
        Panic(EViewError);
        }
    }

// End of File  
